Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
mall/__init__.py | 3 | 0 | 0 | 100%
mall/data.py | 3 | 0 | 0 | 100%
mall/llm.py | 93 | 4 | 0 | 96%
mall/polars.py | 47 | 3 | 0 | 94%
mall/prompt.py | 52 | 2 | 0 | 96%
tests/__init__.py | 0 | 0 | 0 | 100%
tests/test_classify.py | 18 | 1 | 0 | 94%
tests/test_extract.py | 23 | 1 | 0 | 96%
tests/test_sentiment.py | 31 | 1 | 0 | 97%
tests/test_summarize.py | 18 | 1 | 0 | 94%
tests/test_translate.py | 13 | 1 | 0 | 92%
tests/test_use.py | 18 | 0 | 0 | 100%
tests/test_verify.py | 18 | 1 | 0 | 94%
Total | 337 | 15 | 0 | 96%

No items found using the specified filter.